@@ -34,7 +34,7 @@ def create_heatmap(episodes: list[Episode]) -> np.ndarray:
     return heatmap
 
 def heatmap_plot(series_name: str, episodes: List[Episode], show: bool, save_fn: str or None,
-                 dark_mode: bool, save_buffer=None, dpi=100, dark_col=(0.16, 0.16, 0.16, 1.0)) -> None:
+                 dark_mode: bool, save_buffer=None, save_buffer_format='png', dpi=100, dark_col=(0.16, 0.16, 0.16, 1.0)) -> None:
     # create the heatmap array
     heatmap = create_heatmap(episodes)
 
@@ -81,7 +81,7 @@ def heatmap_plot(series_name: str, episodes: List[Episode], show: bool, save_fn:
 
     # save plot to buffer if provided
     if save_buffer is not None:
-        plt.savefig(save_buffer, format='png')
+        plt.savefig(save_buffer, format=save_buffer_format)
         save_buffer.seek(0)
 
     # optionally save or display the plot
